@@ -1,20 +1,17 @@
 from copy import deepcopy
 from lyrebird import application
-from lyrebird.log import get_logger
-from .flow_editor_handler import FlowEditorHandler
-
-logger = get_logger()
+from .function_executor import FunctionExecutor
 
 
-class EncoderDecoder:
+class EncoderDecoder(FunctionExecutor):
     def __init__(self):
         self.encoder = application.encoder
         self.decoder = application.decoder
 
     def encoder_handler(self, flow, output=None):
-        matched_funcs = FlowEditorHandler._get_matched_handler(self.encoder, flow)
+        matched_funcs = EncoderDecoder.get_matched_handler(self.encoder, flow)
         if output == None:
-            FlowEditorHandler._func_handler(matched_funcs, flow)
+            EncoderDecoder.func_handler(matched_funcs, flow, handler_type='encoder')
             return
 
         if not matched_funcs:
@@ -22,13 +19,13 @@ class EncoderDecoder:
             return
 
         new_flow = deepcopy(flow)
-        FlowEditorHandler._func_handler(matched_funcs, new_flow)
+        EncoderDecoder.func_handler(matched_funcs, new_flow, handler_type='encoder')
         output.update(new_flow)
 
     def decoder_handler(self, flow, output=None):
-        matched_funcs = FlowEditorHandler._get_matched_handler(self.decoder, flow)
+        matched_funcs = EncoderDecoder.get_matched_handler(self.decoder, flow)
         if output == None:
-            FlowEditorHandler._func_handler(matched_funcs, flow)
+            EncoderDecoder.func_handler(matched_funcs, flow, handler_type='decoder')
             return
 
         if not matched_funcs:
@@ -36,7 +33,5 @@ class EncoderDecoder:
             return
 
         new_flow = deepcopy(flow)
-        FlowEditorHandler._func_handler(matched_funcs, new_flow)
+        EncoderDecoder.func_handler(matched_funcs, new_flow, handler_type='decoder')
         output.update(new_flow)
-
-encoders_decoders = EncoderDecoder()
